@@ -17,8 +17,7 @@ import hashlib
 
 class ml3:
     def __init__(self):
-    self.apimap = {}
-    
+        pass 
 
     #LOG,INFO,WARN,ERROR,
     def intro():
